import { Typography, styled } from "@mui/material";
import React, { useEffect, useState } from "react";
import { Document } from "../../accessor/document";

type ComicType = "comic" | "artist cg" | "donjinshi" | "western";

export type PresentableTag = {
    artist: string[];
    group: string[];
    series: string[];
    type: ComicType;
    character: string[];
    tags: string[];
};

const ViewMain = styled("div")(({ theme }) => ({
    overflow: "hidden",
    width: "100%",
    height: "calc(100vh - 64px)",
    position: "relative",
}));
const CurrentView = styled("img")(({theme})=>({
    maxWidth: "100%", 
    maxHeight: "100%", 
    top:"50%", 
    left:"50%",
    transform: "translate(-50%,-50%)",
    position: "absolute"
})); 

export const ComicReader = (props: { doc: Document }) => {
    const additional = props.doc.additional;
    const [curPage, setCurPage] = useState(0);
    if (!("page" in additional)) {
        console.error("invalid content : page read fail : " + JSON.stringify(additional));
        return <Typography>Error. DB error. page restriction</Typography>;
    }
    const PageDown = () => setCurPage(Math.max(curPage - 1, 0));
    const PageUp = () => setCurPage(Math.min(curPage + 1, page - 1));
    const page: number = additional["page"] as number;
    const onKeyUp = (e: KeyboardEvent) => {
        if (e.code === "ArrowLeft") {
            PageDown();
        } else if (e.code === "ArrowRight") {
            PageUp();
        }
    };
    useEffect(() => {
        document.addEventListener("keydown", onKeyUp);
        return () => {
            document.removeEventListener("keydown", onKeyUp);
        };
    });
    // theme.mixins.toolbar.minHeight;
    return (
        <ViewMain>
            <div onClick={PageDown} style={{left:"0", width: "50%", position:"absolute", height: "100%", zIndex:100}}></div>
            <CurrentView
                onClick={PageUp}
                src={`/api/doc/${props.doc.id}/comic/${curPage}`}
            ></CurrentView>
            <div onClick={PageUp} style={{right:"0", width: "50%", position:"absolute", height: "100%", zIndex:100}}></div>
        </ViewMain>
    );
};

export default ComicReader;
